# FAQ
???+ "Why did you create this library ?"

    I wanted a library that did not depend on any non-python tools (so you had to go around and install that). Instead, I wanted a library where you install the pip packages and you are done.
    Later I realised how hard it was to integrate correctly with PyOBJC. Also, I had a hard time finding any examples on how to easily integrate this in a non-blocking fashion with my tool. 
    Hence, I figured I should set it up to be as user-friendly as possible and share it with the world ;)!


???+ "My notifications don't show up with the text I mentioned"

    Unfortunately, you first need to allow Python to create notifications. Instructions on this can be found [here](https://www.jetbrains.com/idea/guide/tips/enable-soft-wrap/#:~:text=You%20can%20enable%20soft%20wrap,more%20file%20types%20by%20default.). Check below for an example


Your settings should look similar to this:

![](img/enable-notifications.png)
        
